@@ -306,17 +306,24 @@ if sys.platform not in ["win32", "darwin"]:
 
 # Can force the use of OpenMP with this variable.
 try:
-    USE_OPENMP = eval(os.environ.get("USE_OPENMP", "None").title())
+    USE_OPENMP = eval(os.environ.get("USE_OPENMP", "False").title())
 except Exception:
-    USE_OPENMP = None
+    USE_OPENMP = False
 
 tdl_build = os.environ.get("TDL_BUILD", "RELEASE").upper()
 
 MSVC_CFLAGS = {"DEBUG": ["/Od"], "RELEASE": ["/GL", "/O2", "/GS-", "/wd4996"]}
 MSVC_LDFLAGS = {"DEBUG": [], "RELEASE": ["/LTCG"]}
 GCC_CFLAGS = {
-    "DEBUG": ["-Og", "-g", "-fPIC"],
-    "RELEASE": ["-flto", "-O3", "-g", "-fPIC", "-Wno-deprecated-declarations"],
+    "DEBUG": ["-std=c99", "-Og", "-g", "-fPIC"],
+    "RELEASE": [
+        "-std=c99",
+        "-flto",
+        "-O3",
+        "-g",
+        "-fPIC",
+        "-Wno-deprecated-declarations",
+    ],
 }
 
 if sys.platform == "win32" and "--compiler=mingw32" not in sys.argv:
